#
# spec file for package ghc-commonmark-extensions
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name commonmark-extensions
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.2.5.6
Release:        1.2
Summary:        Pure Haskell commonmark parser
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-commonmark-devel
BuildRequires:  ghc-commonmark-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-emojis-devel
BuildRequires:  ghc-emojis-prof
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-filepath-prof
BuildRequires:  ghc-network-uri-devel
BuildRequires:  ghc-network-uri-prof
BuildRequires:  ghc-parsec-devel
BuildRequires:  ghc-parsec-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-hunit-prof
BuildRequires:  ghc-tasty-prof
%endif

%description
This library provides some useful extensions to core commonmark syntax: smart
quotes, definition lists, tables, footnotes, math, and more.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc README.md changelog.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Sun Dec  8 2024 Peter Simons <psimons@suse.com>
- Update commonmark-extensions to version 0.2.5.6.
  [#]# 0.2.5.6
  * Autolink parser: track balanced brackets in path (improves
    on #156). We still get a link within a link, which isn't right, but at
    least the link goes to the right place. Cf. jgm/pandoc#10333.
* Tue Jun 18 2024 Peter Simons <psimons@suse.com>
- Update commonmark-extensions to version 0.2.5.5.
  [#]# 0.2.5.5
  * Fix auto_identifiers extension: it now replaces emojis with
    their aliases, as documented.
  * Fix auto_identifiers_ascii extension: it now ignores
    non-ASCII characters with no ASCII equivalent.
* Mon Mar 11 2024 Peter Simons <psimons@suse.com>
- Update commonmark-extensions to version 0.2.5.4.
  [#]# 0.2.5.4
  * Fix autolink parsing regression (#151). This affects autolinks with
    doubled internal line-ending punctuation characters.
* Wed Feb 28 2024 Peter Simons <psimons@suse.com>
- Update commonmark-extensions to version 0.2.5.3.
  [#]# 0.2.5.3
  * Fix rebase_relative_paths extension so it works with URLs with
    non-ASCII characters (#148). Previously these would not be properly
    detected as absolute URIs.
* Thu Feb 15 2024 Peter Simons <psimons@suse.com>
- Update commonmark-extensions to version 0.2.5.2.
  [#]# 0.2.5.2
  * Improve autolinks extension (#147).
    The autolinks extension was interacting badly with explicit links,
    To fix this we had to make autolink parsing a bit stricter than
    the GFM spec does.  They allow unbalanced `)` except at the end
    of a URL (which is defined as: followed by optional final punctuation
    then whitespace or eof).  With this change, we don't allow unbalanced
    `)` at all in raw URLs. This should not be a big problem in practice.
  * Protect against quadratic generated table size explosion (Michael Howell).
    This commit adds a limit to the number of auto-completed cells
    around 200,000. The result is, in these original samples:
* Tue Dec 12 2023 Peter Simons <psimons@suse.com>
- Update commonmark-extensions to version 0.2.5.1.
  [#]# 0.2.5.1
  * Add `test/alerts.md` to extra-source-files in cabal file.
* Mon Dec 11 2023 Peter Simons <psimons@suse.com>
- Update commonmark-extensions to version 0.2.5.
  [#]# 0.2.5
  * Add support for alerts extension, supporting GitHub-style alerts (#132).
    <https://docs.github.com/en/get-started/writing-on-github/getting-started-with-writing-and-formatting-on-github/basic-writing-and-formatting-syntax#alerts>
    New module Commonmark.Extensions.Alerts [API change].
  * Do not accept footnote labels with line breaks (Michael Howell).
  * Parse `[^ ]` and `[^]` as links (Michael Howell). This is consistent with
    most other CommonMark parsers, even when they have support for footnotes turned on.
* Fri Oct 27 2023 Peter Simons <psimons@suse.com>
- Update commonmark-extensions to version 0.2.4.
  [#]# 0.2.4
  * Make `pipe_tables` extension treat backslash escapes like GH does (#112,
    Michael Howell). This change essentially changes the way the text
    `\\|` gets parsed inside a table. In the old version, the first backslash
    escapes the second backslash, and then the pipe is treated as a cell
    separator. In the new version, the pipe is still preceded by a backslash,
    so it is still literal text. The escaping rule is documented in detail
    in the spec for this extension. This change also aligns our escaping
    of pipes with GitHub's.
* Wed Sep 13 2023 Peter Simons <psimons@suse.com>
- Update commonmark-extensions to version 0.2.3.6.
  [#]# 0.2.3.6
  * Fix pipe table parser so that `|`s don't interfere with
    other block structures (Michael Howell, #111, fixing #52 and
    [#95]). This parser is structured as a system that parses the
  * second* line first, then parses the first line. That is, if
    it detects a delimiter row as the second line of a
    paragraph, it converts the paragraph into a table. This
    seems counterintuitive, but it works better than trying to
    convert a table into a paragraph, since it might need to be
    something else.
  * Improve parsing of inline math (#110).
* Wed Jul 12 2023 Peter Simons <psimons@suse.com>
- Update commonmark-extensions to version 0.2.3.5.
  [#]# 0.2.3.5
  - Resolve entities inside wikilinks (#105, Michał Kukieła).
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Sat Mar  4 2023 Peter Simons <psimons@suse.com>
- Update commonmark-extensions to version 0.2.3.4.
  [#]# 0.2.3.4
  - Require whitespace after definition list marker (#104).
    Otherwise we can inadvertently clobber strikeout or subscript.
* Thu Sep 29 2022 Peter Simons <psimons@suse.com>
- Update commonmark-extensions to version 0.2.3.3.
  [#]# 0.2.3.3
  - Fix definition_lists extension (#96). We were not properly consuming
    indentation in definitions, which caused problems when the definitions
    themselves contained lists.
* Tue May 31 2022 Peter Simons <psimons@suse.com>
- Update commonmark-extensions to version 0.2.3.2.
  [#]# 0.2.3.2
  - Update lower version bounds for commonmark (#93, David
    Thrane Christiansen).
* Sat Apr  2 2022 Peter Simons <psimons@suse.com>
- Update commonmark-extensions to version 0.2.3.1.
  [#]# 0.2.3.1
  - `math` extension:  don't fail when display math contains
    embedded inline math.  See jgm/pandoc#7942.
  - Make math parsing more sophisticated.
    Count embeddings inside `{..}`, since math can contain
    e.g. `\text{...}` which itself contains math delimiters.
  - Small improvement in pipe table parsing.
    The old parser failed on some edge cases with extra whitespace
    after pipes (which we should just ignore).
  - `fancy_list` extension: improve list type ambiguity resolution (#89).
* Wed Jan 12 2022 Peter Simons <psimons@suse.com>
- Update commonmark-extensions to version 0.2.3.
  [#]# 0.2.3
  - Allow bare word attribute in fenced_divs (#84).  This follows a similar
    change in pandoc (jgm/pandoc#7242).
* Mon Nov  1 2021 psimons@suse.com
- Add commonmark-extensions at version 0.2.2.1.
* Sun May 30 2021 psimons@suse.com
- Update commonmark-extensions to version 0.2.1.2.
  [#]# 0.2.1.2
  - Fix bug with absolute paths in rebase_relative_paths
    extension on Windows.
* Sat May 29 2021 psimons@suse.com
- Update commonmark-extensions to version 0.2.1.1.
  [#]# 0.2.1.1
  - Fix bug in wikilinks extensions.
  [#]# 0.2.1
  - Add `rebase_relative_paths` extension.
    New exported module Commonmark.Extensions.RebaseRelativePaths [API change].
  - Add `wikilinks_title_before_pipe` and `wikilinks_title_after_pipe`
    extensions (#69).
    New exported module Commonmark.Extensions.Wikilinks [API change].
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Sat Nov  7 2020 psimons@suse.com
- Update commonmark-extensions to version 0.2.0.4.
  [#]# 0.2.0.4
  - Add a test for autolinks (#66).
  - Require commonmark 0.1.1.2 (otherwise autolinks don't work
    properly).
  [#]# 0.2.0.3
  - Add some new test examples to the autolinks extension spec (#65).
  - Allow interior `~` characters in autolinks (#65).
* Tue Nov  3 2020 psimons@suse.com
- Update commonmark-extensions to version 0.2.0.2.
  [#]# 0.2.0.2
  - Remove unnecessary Typeable constraint on `TaskList` and
    `gfmExtensions` (#58).
  - Fix bug in `footnote` extension:  multiple blocks in
    a block container (e.g. block quote or list) inside
    a footnote were being rendered in reverse order (#63,
    Harald Gliebe).
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Aug  4 2020 psimons@suse.com
- Add commonmark-extensions at version 0.2.0.1.
